@@ -8,17 +8,17 @@ __author__ = 'https://github.com/akvilary'
 import uuid
 
 from sqlconstructor.utils.classes.string_convertible import StringConvertible
-from sqlconstructor.utils.classes.special_convertion_requier import SpecialConvertionRequier
+from sqlconstructor.utils.classes.sql_convertion_requier import SqlConvertionRequier
 from . import to_sql_string
 from . import to_array
 from . import to_json
 
 
-def convert_any_to_sql(value) -> str:
+def convert_any_to_sql(value, is_json_context: bool = False) -> str:
     """Convert any value to sql representation"""
     if isinstance(value, str):
-        return to_sql_string.convert_python_str_to_sql_str(value)
-    if isinstance(value, SpecialConvertionRequier):
+        return to_sql_string.convert_python_str_to_sql_str(value, is_json_context)
+    if isinstance(value, SqlConvertionRequier):
         return value.__as_sql__()
     if isinstance(value, StringConvertible):
         return str(value)
